@@ -10,7 +10,7 @@
 
 KM <- function(Stime, status){
 	n_time <- length(Stime)
-	km <- .C("C_km_Daim", 
+	km <- .C(`C_km_Daim`, 
 			 vector("numeric", length(Stime)), 
 			 as.numeric(Stime), 
 			 as.numeric(status), 
@@ -38,7 +38,7 @@ weightKM <- function(Stime, status, wt=NULL, entry=NULL ){
 		entry <- vector("numeric",n_time)
 	if( is.null(wt) ) 
 		wt <- vector("numeric",n_time)+1
-	km <- .C("C_km_weight", 
+	km <- .C(`C_km_weight`, 
 			 vector("numeric", n_time), 
 			 as.numeric(Stime), 
 			 as.numeric(status), 
@@ -67,7 +67,7 @@ cox_weights <- function(marker, time, status, thresh, entry=NULL){
 	n_time <- length(time)
 	if( is.null(entry) )  
 		entry <- vector("numeric",n_time)
-	ans <- .C("C_cox_weights", 
+	ans <- .C(`C_cox_weights`, 
 			 as.numeric(marker), 
 			 as.numeric(time), 
 			 as.integer(status), 
