@@ -7,6 +7,6 @@
  *
  */
 
-void Hung_Chiang(double *time, int *n_time, double *stime, double *event, int *n_stime,
+void C_Hung_Chiang(double *time, int *n_time, double *stime, double *event, int *n_stime,
 				 double *stime_new, double *event_new, int *n_stime_new,
 				 double *lpnew, int *n_lpnew, double *ans, double *i_auc);
